pub struct KeyDemand {
pub cache_key: String,
pub first_demand_at_ms: u64,
pub remote_wait_ms: u64,
}Expand description
One key requested by a wrapper, including unsuccessful predictions.
Fields
cache_key: Stringfirst_demand_at_ms: u64remote_wait_ms: u64Wall time blocked on remote-check IPC, including daemon admission and failed requests. It is not an estimate of time saved by prefetch.