pub struct TimelineIdentity {
pub lock_digest: Option<String>,
pub identity_key: Option<String>,
pub source: IdentitySource,
}Expand description
What build this was, as far as the client could tell.
Fields
lock_digest: Option<String>Truncated content hash of the root’s Cargo.lock.
identity_key: Option<String>Prefetch identity key (id/{lock}/{target}/{profile}), only when the
profile was known or the key was set explicitly.
source: IdentitySourceTrait Implementations
Sourceimpl Clone for TimelineIdentity
impl Clone for TimelineIdentity
Sourcefn clone(&self) -> TimelineIdentity
fn clone(&self) -> TimelineIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TimelineIdentity
impl Debug for TimelineIdentity
Sourceimpl Default for TimelineIdentity
impl Default for TimelineIdentity
Sourcefn default() -> TimelineIdentity
fn default() -> TimelineIdentity
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TimelineIdentity
impl<'de> Deserialize<'de> for TimelineIdentity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TimelineIdentity
Sourceimpl PartialEq for TimelineIdentity
impl PartialEq for TimelineIdentity
Sourceimpl Serialize for TimelineIdentity
impl Serialize for TimelineIdentity
impl StructuralPartialEq for TimelineIdentity